/**
 * Back 2 Browser Bytecode Translator Copyright (C) 2012 Jaroslav Tulach
 * <jaroslav.tulach@apidesign.org>
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. Look for COPYING file in the top folder. If not, see
 * http://opensource.org/licenses/GPL-2.0.
 */
package net.java.html.canvas;

import java.util.ServiceLoader;

/**
 *
 * @author antonepple
 */
public abstract class GraphicsEnvironment {

    private static GraphicsEnvironment DEFAULT;

    public GraphicsEnvironment getDefault() {
        if (DEFAULT == null) {
            ServiceLoader<GraphicsEnvironment> loader = ServiceLoader.load(GraphicsEnvironment.class);
            DEFAULT = loader.iterator().next();
        }
        return DEFAULT == null ? getDummyInstance() : DEFAULT;
    }

    public abstract Image getImageForPath(String path);
    
    public abstract LinearGradient createLinearGradient();
    
    public abstract Pattern createPattern();
    
    public abstract RadialGradient createRadialGradient();
    
    public abstract TextMetrics createTextMetrics();
    
    private GraphicsEnvironment getDummyInstance() {
        
        return new GraphicsEnvironment() {

            @Override
            public Image getImageForPath(String path) {
               return new Image() {

                   @Override
                   public int getHeight() {
                     return 0;
                   }

                   @Override
                   public int getWidth() {
                       return 0;
                   }
               };
            }

            @Override
            public LinearGradient createLinearGradient() {
                return new LinearGradient() {

                    @Override
                    public void addColorStop(double position, String color) {
                      
                    }
                };
            }

            @Override
            public Pattern createPattern() {
               return new Pattern() {
};
            }

            @Override
            public RadialGradient createRadialGradient() {
                return new RadialGradient() {

                    @Override
                    public void addColorStop(double position, String color) {
                        
                    }
                };
            }

            @Override
            public TextMetrics createTextMetrics() {
                return new TextMetrics() {

                    @Override
                    public double getHeight() {
                        return 0;
                    }

                    @Override
                    public double getWidth() {
                        return 0;
                    }
                };
            }
        };
    }
    
    
}
